﻿
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;
using HeuristicLab.Problems.DataAnalysis;
using HeuristicLab.Data.Views;
using System.Collections.Generic;
using System.Linq;

namespace HeuristicLab.DataPreprocessing {
  [View("Data Grid Content View")]
  [Content(typeof(IDataGridContent), true)]
  public partial class DataGridContentView : StringConvertibleMatrixView {

    public new IDataGridContent Content {
      get { return (IDataGridContent)base.Content; }
      set { base.Content = value; }
    }

    public DataGridContentView() {
      InitializeComponent();
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
    }


    private void dataGridView_CellValidating(object sender, DataGridViewCellValidatingEventArgs e) {
      if (!dataGridView.ReadOnly) {
        string errorMessage;
        if (Content != null && !Content.DataGridLogic.Validate(e.FormattedValue.ToString(), out errorMessage, e.ColumnIndex)) {
          e.Cancel = true;
          dataGridView.Rows[e.RowIndex].ErrorText = errorMessage;
        }
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      rowsTextBox.ReadOnly = true;
      columnsTextBox.ReadOnly = true;
    }

    private void btnApplySort_Click(object sender, System.EventArgs e) {
      Content.PreprocessingDataManipulation.reOrderToIndices(virtualRowIndices);
      OnContentChanged();
    }

    protected override int[] Sort(IEnumerable<KeyValuePair<int, SortOrder>> sortedColumns) {
      btnApplySort.Enabled = sortedColumns.Any();
      return base.Sort(sortedColumns);
    }

    protected override void ClearSorting() {
      btnApplySort.Enabled = false;
      base.ClearSorting();
    }
  }
}
